@@ -1,16 +1,13 @@
-use self::embed::FsOrEmbeddedDirectory;
-pub use self::{
-	builder::{build, BuildOptions},
-	hash::hash,
-};
+pub use self::builder::{build, BuildOptions};
 use anyhow::Result;
+use digest::Digest;
 use futures::FutureExt;
+use include_dir::IncludeDir;
 use std::{future::Future, path::Path, pin::Pin};
-pub use sunfish_macro::{embed, init};
+pub use sunfish_macro::{include_dir, init};
 
 mod builder;
-pub mod embed;
-mod hash;
+pub mod include_dir;
 pub mod watchserve;
 
 pub enum Route {
@@ -116,7 +113,7 @@ type RoutesHandlerOutput<'a> =
 	Pin<Box<dyn 'a + Send + Future<Output = Result<Option<http::Response<hyper::Body>>>>>>;
 
 pub struct Sunfish {
-	pub output: FsOrEmbeddedDirectory,
+	pub output: IncludeDir,
 	pub routes_handler: RoutesHandler,
 }
 
@@ -196,3 +193,12 @@ fn content_type(path: &std::path::Path) -> Option<&'static str> {
 		None
 	}
 }
+
+pub fn hash(bytes: impl AsRef<[u8]>) -> String {
+	let mut hash: sha2::Sha256 = Digest::new();
+	hash.update(bytes);
+	let hash = hash.finalize();
+	let hash = hex::encode(hash);
+	let hash = &hash[0..16];
+	hash.to_owned()
+}
